WIDTH = 600
HEIGHT = 800
TITLE = 'ytdl_gui'
APPID = 'org.sheep.youtube-downloader'
CSSPATH = 'ytdl_gui/css/style.css'
